timesignaturetools
==================

.. automodule:: abjad.tools.timesignaturetools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.timesignaturetools.MetricalHierarchy.MetricalHierarchy.MetricalHierarchy
      ~abjad.tools.timesignaturetools.MetricalHierarchyInventory.MetricalHierarchyInventory.MetricalHierarchyInventory
      ~abjad.tools.timesignaturetools.MetricalKernel.MetricalKernel.MetricalKernel

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.timesignaturetools.duration_and_possible_denominators_to_time_signature.duration_and_possible_denominators_to_time_signature
      ~abjad.tools.timesignaturetools.establish_metrical_hierarchy.establish_metrical_hierarchy
      ~abjad.tools.timesignaturetools.fit_metrical_hierarchies_to_expr.fit_metrical_hierarchies_to_expr
      ~abjad.tools.timesignaturetools.make_gridded_test_rhythm.make_gridded_test_rhythm
